<?php
/**
 * The Giapeto_Bookmarks_sql:: class provides the SQL driver for storing
 * Giapeto bookmarks.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: giapeto/lib/Bookmarks/sql.php,v 1.12 2005/01/03 14:34:52 jan Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.12 $
 * @package Giapeto
 */
class Giapeto_Bookmarks_sql extends Giapeto_Bookmarks {

    var $_db;

    function saveBookmark(&$info)
    {
        if (empty($info['bookmark_id'])) {
            $sql = sprintf('SELECT * FROM giapeto_bookmarks' .
                           ' WHERE page_id = %s AND user_uid = %s',
                           (int)$info['page_id'],
                           $this->_db->quote(Auth::getAuth()));
            $result = $this->_db->getRow($sql, DB_FETCHMODE_ASSOC);
            if (!empty($result['bookmark_id'])) {
                $info['bookmark_id'] = $result['bookmark_id'];
            } else {
                $info['bookmark_id'] = $this->_db->nextId('giapeto_bookmarks');
                if (is_a($info['bookmark_id'], 'PEAR_Error')) {
                    return $info['bookmark_id'];
                }
            }
            /* Delete existing bookmark. */
            $sql = 'DELETE FROM giapeto_bookmarks WHERE bookmark_id = ' . (int)$info['bookmark_id'];
            Horde::logMessage('SQL Query by Giapeto_Bookmarks_sql::saveBookmark(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
            $delete = $this->_db->query($sql);
            if (is_a($delete, 'PEAR_Error')) {
                return $delete;
            }

            /* Save the updated bookmark. */
            $sql_sprintf = 'INSERT INTO giapeto_bookmarks (bookmark_id, user_uid, page_id, bookmark_alert, bookmark_subpages) VALUES(%s, %s, %s, %s, %s)';
        } else {
            $sql_sprintf = 'UPDATE giapeto_bookmarks SET bookmark_id = %s, user_uid = %s, page_id = %s, bookmark_alert = %s, bookmark_subpages = %s' . sprintf(' WHERE bookmark_id = %s', (int)$info['bookmark_id']);
        }

        $sql = sprintf($sql_sprintf,
                       (int)$info['bookmark_id'],
                       $this->_db->quote(Auth::getAuth()),
                       (int)$info['page_id'],
                       ($info['bookmark_alert'] ? '1' : '0'),
                       ($info['bookmark_subpages'] ? '1' : '0'));

        Horde::logMessage('SQL Query by Giapeto_Bookmarks_sql::saveBookmark(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->query($sql);
        if (is_a($result, 'PEAR_Error')) {
            return $result;
        }

        return $info['bookmark_id'];
    }

    function _getBookmarks()
    {
        $sql = sprintf('SELECT * FROM giapeto_bookmarks WHERE user_uid = %s',
                       $this->_db->quote(Auth::getAuth()));

        $result = $this->_db->getAll($sql, DB_FETCHMODE_ASSOC);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
            return array();
        }

        return $result;
    }

    function _getAllBookmarks()
    {
        return $this->_db->getAll('SELECT * FROM giapeto_bookmarks', DB_FETCHMODE_ASSOC);
    }

    function isBookmarked($page_id)
    {
        $sql = sprintf('SELECT * FROM giapeto_bookmarks WHERE page_id = %s AND user_uid = %s',
                       (int)$page_id,
                       $this->_db->quote(Auth::getAuth()));
        $result = $this->_db->getOne($sql);
        return (!empty($result));
    }

    function getBookmark($bookmark_id, $with_path = false)
    {
        $sql = sprintf('SELECT * FROM giapeto_bookmarks WHERE bookmark_id = %s AND user_uid = %s',
                       (int)$bookmark_id,
                       $this->_db->quote(Auth::getAuth()));
        Horde::logMessage('SQL Query by Giapeto_Bookmarks_sql::getBookmark(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getRow($sql, DB_FETCHMODE_ASSOC);

        if ($with_path) {
            $result['path'] = $GLOBALS['registry']->call('cms/getPageUrl', array($result['page_id']));
        }

        return $result;
    }

    function deleteBookmark($bookmark_id)
    {
        /* Delete the form. */
        $sql = sprintf('DELETE FROM giapeto_bookmarks WHERE bookmark_id = %s',
                       (int)$bookmark_id);
        $delete = $this->_db->query($sql);
        return $delete;
    }

    function initialise()
    {
        Horde::assertDriverConfig($this->_params, 'sql',
            array('phptype', 'hostspec', 'username', 'database'));

        /* Connect to the SQL server using the supplied parameters. */
        require_once 'DB.php';
        $this->_db = &DB::connect($this->_params,
                                  array('persistent' => !empty($this->_params['persistent'])));
        if (is_a($this->_db, 'PEAR_Error')) {
            Horde::fatal($this->_db, __FILE__, __LINE__);
        }

        $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);

        return true;
    }

}
