<?php
/**
 * The Giapeto_Stats_sql:: class provides the SQL driver for storing Giapeto
 * page statistics.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: giapeto/lib/Stats/sql.php,v 1.9 2005/01/03 14:34:53 jan Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.9 $
 * @package Giapeto
 */
class Giapeto_Stats_sql extends Giapeto_Stats {

    var $_db;

    function _log($log)
    {
        $log['stats_id'] = $this->_db->nextId('giapeto_stats');
        if (is_a($log['stats_id'], 'PEAR_Error')) {
            return $log['stats_id'];
        }

        $sql = sprintf('INSERT INTO giapeto_stats (stats_id, user_uid, page_id, stats_url, stats_time) VALUES(%s, %s, %s, %s, %s)',
                       (int)$log['stats_id'],
                       $this->_db->quote($log['user']),
                       (int)$log['page_id'],
                       $this->_db->quote($log['url']),
                       (int)$log['time']);
        $result = $this->_db->query($sql);
        if (is_a($result, 'PEAR_Error')) {
            return $result;
        }

        return $log['stats_id'];
    }

    function getFirstVisit($page_id)
    {
        $sql = sprintf('SELECT MIN(stats_time) FROM giapeto_stats WHERE page_id = %s',
                       (int)$page_id);

        $result = $this->_db->getOne($sql);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
            return false;
        }

        return $result;
    }

    function getLastVisit($page_id)
    {
        $sql = sprintf('SELECT MAX(stats_time) FROM giapeto_stats WHERE page_id = %s',
                       (int)$page_id);

        $result = $this->_db->getOne($sql);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
            return false;
        }

        return $result;
    }

    function getTotalViews($page_id)
    {
        $sql = sprintf('SELECT COUNT(stats_id) FROM giapeto_stats WHERE page_id = %s',
                       (int)$page_id);

        $result = $this->_db->getOne($sql);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
            return false;
        }

        return $result;
    }

    function getTotalUsers($page_id)
    {
        $sql = sprintf('SELECT DISTINCT COUNT(user_uid) FROM giapeto_stats WHERE page_id = %s GROUP BY user_uid',
                       (int)$page_id);

        $result = $this->_db->getOne($sql);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
            return false;
        }

        return $result;
    }

    function initialise()
    {
        Horde::assertDriverConfig($this->_params, 'storage',
            array('phptype', 'hostspec', 'username', 'database'));

        /* Connect to the SQL server using the supplied parameters. */
        require_once 'DB.php';
        $this->_db = &DB::connect($this->_params,
                                  array('persistent' => !empty($this->_params['persistent'])));
        if (is_a($this->_db, 'PEAR_Error')) {
            Horde::fatal($this->_db, __FILE__, __LINE__);
        }

        $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);

        return true;
    }

}
